==> openGion_dev_5.7.5.0.zip: opengion/uap/webapps/gf/db/postgres/sql/install/01_TABLE/GF80S.sql <==
/****************************************************************************/
/* GF80 ( DB定義書ﾏｽﾀ )                                                     */
/*                                                                          */
/* Created : 2014/03/26 15:25:48                                            */
/****************************************************************************/
CREATE TABLE GF80 (
   SYSTEM_ID    VARCHAR (   10 )                    NOT NULL            /*  10 ｼｽﾃﾑID       */
 , TBLSYU       VARCHAR (    1 )                    NOT NULL            /*  20 ﾃｰﾌﾞﾙ種別    */
 , TABLE_NAME   VARCHAR (   50 )                    NOT NULL            /*  30 ﾃｰﾌﾞﾙ名      */
 , NAME_JA      VARCHAR (  200 )                                        /*  40 名称         */
 , SEQNO        INTEGER                 DEFAULT 0   NOT NULL            /*  50 表示順       */
 , CLM_NAME     VARCHAR (  120 )                                        /*  60 項目名(漢字) */
 , CLM          VARCHAR (   30 )                    NOT NULL            /*  70 項目         */
 , CLS_NAME     VARCHAR (   10 )                    NOT NULL            /*  80 DBｸﾗｽ        */
 , PHY_LENGTH   VARCHAR (   10 )                                        /*  90 物理桁数     */
 , USE_LENGTH   VARCHAR (    9 )                                        /* 100 使用桁数     */
 , LUK          VARCHAR (    2 )                                        /* 110 論理ﾕﾆｰｸｷｰ   */
 , UK           VARCHAR (    2 )                                        /* 110 ﾕﾆｰｸｷｰ       */
 , IXA          VARCHAR (    2 )                                        /* 120 ｲﾝﾃﾞｯｸｽA     */
 , IXB          VARCHAR (    2 )                                        /* 130 ｲﾝﾃﾞｯｸｽB     */
 , IXC          VARCHAR (    2 )                                        /* 140 INDEXｺｰﾄﾞ    */
 , IXD          VARCHAR (    2 )                                        /* 150 ｲﾝﾃﾞｯｸｽD     */
 , IXH          VARCHAR (    2 )                                        /* 150 ｲﾝﾃﾞｯｸｽH     */
 , IXE          VARCHAR (    2 )                                        /* 160 ｲﾝﾃﾞｯｸｽE     */
 , IXI          VARCHAR (    2 )                                        /* 160 ｲﾝﾃﾞｯｸｽI     */
 , IXF          VARCHAR (    2 )                                        /* 170 ｲﾝﾃﾞｯｸｽF     */
 , IXJ          VARCHAR (    2 )                                        /* 170 ｲﾝﾃﾞｯｸｽJ     */
 , IXG          VARCHAR (    2 )                                        /* 180 ｲﾝﾃﾞｯｸｽG     */
 , IXK          VARCHAR (    2 )                                        /* 180 ｲﾝﾃﾞｯｸｽK     */
 , NOT_NULL     VARCHAR (    1 )                                        /* 190 ﾉｯﾄﾇﾙ        */
 , C_KEY        VARCHAR (    1 )                                        /* 200 C_KEY        */
 , F_KEY        VARCHAR (    1 )                                        /* 210 ﾌｫｰﾘﾝｷｰ      */
 , RENDERER     VARCHAR (   10 )                                        /* 220 表示種別     */
 , EDITOR       VARCHAR (   10 )                                        /* 230 編集種別     */
 , DBTYPE       VARCHAR (   10 )                                        /* 240 文字種別     */
 , DATA_DEFAULT VARCHAR (  200 )                                        /* 250 初期値       */
 , KBCLM        VARCHAR (    1 )        DEFAULT '0' NOT NULL            /* 260 ｶﾗﾑ区分      */
 , BIKO         VARCHAR ( 2000 )                                        /* 270 備考         */
 , CDKH         VARCHAR (    1 )                                        /* 280 改廃ｺｰﾄﾞ     */
 , COMMENTS     VARCHAR (  500 )                                        /* 290 ｺﾒﾝﾄ         */
 , UNIQ         SERIAL                                                  /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR (    1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR (   14 )                                        /* 820 登録日時     */
 , PGSET        VARCHAR (   10 )                                        /* 830 作成PG       */
 , PGPSET       VARCHAR (   10 )                                        /* 840 作成親PG     */
 , USRSET       VARCHAR (   10 )                                        /* 850 作成社員     */
 , DYUPD        VARCHAR (   14 )                                        /* 860 更新日時     */
 , PGUPD        VARCHAR (   10 )                                        /* 870 更新PG       */
 , PGPUPD       VARCHAR (   10 )                                        /* 880 更新親PG     */
 , USRUPD       VARCHAR (   10 )                                        /* 890 更新者       */
);

==> openGion_dev_5.7.8.0.zip: opengion/uap/webapps/gf/db/postgres/sql/install/01_TABLE/GF80S.sql <==
/****************************************************************************/
/* GF80 ( DB定義書ﾏｽﾀ )                                                     */
/*                                                                          */
/* Created : 2014/06/13 18:57:48                                            */
/****************************************************************************/
CREATE TABLE GF80 (
   SYSTEM_ID    VARCHAR (   10 )                    NOT NULL            /*  10 ｼｽﾃﾑID       */
 , TBLSYU       VARCHAR (    1 )                    NOT NULL            /*  20 ﾃｰﾌﾞﾙ種別    */
 , TABLE_NAME   VARCHAR (   50 )                    NOT NULL            /*  30 ﾃｰﾌﾞﾙ名      */
 , NAME_JA      VARCHAR (  200 )                                        /*  40 名称         */
 , SEQNO        INTEGER                 DEFAULT 0   NOT NULL            /*  50 表示順       */
 , CLM_NAME     VARCHAR (  120 )                                        /*  60 項目名(漢字) */
 , CLM          VARCHAR (   30 )                    NOT NULL            /*  70 項目         */
 , CLS_NAME     VARCHAR (   10 )                    NOT NULL            /*  80 DBｸﾗｽ        */
 , PHY_LENGTH   VARCHAR (   10 )                                        /*  90 物理桁数     */
 , USE_LENGTH   VARCHAR (    9 )                                        /* 100 使用桁数     */
 , LUK          VARCHAR (    2 )                                        /* 110 論理ﾕﾆｰｸｷｰ   */
 , UK           VARCHAR (    2 )                                        /* 110 ﾕﾆｰｸｷｰ       */
 , IXA          VARCHAR (    2 )                                        /* 120 ｲﾝﾃﾞｯｸｽA     */
 , IXB          VARCHAR (    2 )                                        /* 130 ｲﾝﾃﾞｯｸｽB     */
 , IXC          VARCHAR (    2 )                                        /* 140 ｲﾝﾃﾞｯｸｽC     */
 , IXD          VARCHAR (    2 )                                        /* 150 ｲﾝﾃﾞｯｸｽD     */
 , IXH          VARCHAR (    2 )                                        /* 150 ｲﾝﾃﾞｯｸｽH     */
 , IXE          VARCHAR (    2 )                                        /* 160 ｲﾝﾃﾞｯｸｽE     */
 , IXI          VARCHAR (    2 )                                        /* 160 ｲﾝﾃﾞｯｸｽI     */
 , IXF          VARCHAR (    2 )                                        /* 170 ｲﾝﾃﾞｯｸｽF     */
 , IXJ          VARCHAR (    2 )                                        /* 170 ｲﾝﾃﾞｯｸｽJ     */
 , IXG          VARCHAR (    2 )                                        /* 180 ｲﾝﾃﾞｯｸｽG     */
 , IXK          VARCHAR (    2 )                                        /* 180 ｲﾝﾃﾞｯｸｽK     */
 , NOT_NULL     VARCHAR (    1 )                                        /* 190 ﾉｯﾄﾇﾙ        */
 , C_KEY        VARCHAR (    1 )                                        /* 200 C_KEY        */
 , F_KEY        VARCHAR (    1 )                                        /* 210 ﾌｫｰﾘﾝｷｰ      */
 , RENDERER     VARCHAR (   10 )                                        /* 220 表示種別     */
 , EDITOR       VARCHAR (   10 )                                        /* 230 編集種別     */
 , DBTYPE       VARCHAR (   10 )                                        /* 240 文字種別     */
 , DATA_DEFAULT VARCHAR (  200 )                                        /* 250 初期値       */
 , KBCLM        VARCHAR (    1 )        DEFAULT '0' NOT NULL            /* 260 ｶﾗﾑ区分      */
 , BIKO         VARCHAR ( 2000 )                                        /* 270 備考         */
 , CDKH         VARCHAR (    1 )                                        /* 280 改廃ｺｰﾄﾞ     */
 , COMMENTS     VARCHAR (  500 )                                        /* 290 ｺﾒﾝﾄ         */
 , UNIQ         SERIAL                                                  /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR (    1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR (   14 )                                        /* 820 登録日時     */
 , PGSET        VARCHAR (   10 )                                        /* 830 作成PG       */
 , PGPSET       VARCHAR (   10 )                                        /* 840 作成親PG     */
 , USRSET       VARCHAR (   10 )                                        /* 850 作成社員     */
 , DYUPD        VARCHAR (   14 )                                        /* 860 更新日時     */
 , PGUPD        VARCHAR (   10 )                                        /* 870 更新PG       */
 , PGPUPD       VARCHAR (   10 )                                        /* 880 更新親PG     */
 , USRUPD       VARCHAR (   10 )                                        /* 890 更新者       */
);
